/*
 * Copyright (C) 2013 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Modified by Octoshape 2015.
 * Initially named "VideoBrowserActivity"
 */

package octoshape.android;

import android.annotation.TargetApi;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.support.v7.app.MediaRouteButton;
import android.support.v7.media.MediaRouter.RouteInfo;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;

import com.github.amlcurran.showcaseview.ShowcaseView;
import com.github.amlcurran.showcaseview.targets.ViewTarget;
import com.google.sample.cast.refplayer.settings.CastPreference;
import com.google.android.libraries.cast.companionlibrary.cast.VideoCastManager;
import com.google.android.libraries.cast.companionlibrary.cast.callbacks.VideoCastConsumer;
import com.google.android.libraries.cast.companionlibrary.cast.callbacks.VideoCastConsumerImpl;
import com.google.android.libraries.cast.companionlibrary.cast.exceptions.NoConnectionException;
import com.google.android.libraries.cast.companionlibrary.cast.exceptions.TransientNetworkDisconnectionException;
import com.google.android.libraries.cast.companionlibrary.widgets.MiniController;
import com.octoshape.android.client.OctoStatic;
import octoshape.android.R;
import android.os.Handler;
import com.google.sample.cast.refplayer.settings.CastPreference;


import octoshape.osa2.Problem;
import octoshape.osa2.listeners.ProblemListener;


public class ClientActivity extends ActionBarActivity implements ProblemListener {

    private static final String TAG = "ClientActivity";
    private VideoCastManager castManager;
    private VideoCastConsumer castConsumer;
    private MiniController mMini;
    private Integer currentMediaPosition = null;

    private MenuItem mediaRouteMenuItem;
    private MediaRouteButton mediaRouteButton;
    boolean mIsHoneyCombOrAbove = Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB;
    private Toolbar mToolbar;

    /*
     * (non-Javadoc)
     * @see android.support.v4.app.FragmentActivity#onCreate(android.os.Bundle)
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        VideoCastManager.checkGooglePlayServices(this);
        setContentView(R.layout.cast_application);

        castManager = CastApplication.getCastManager();

        // -- Adding MiniController
        mMini = (MiniController) findViewById(R.id.miniController1);
        castManager.addMiniController(mMini);

        castConsumer = new VideoCastConsumerImpl() {

            @Override
            public void onFailed(int resourceId, int statusCode) {

            }

            @Override
            public void onConnectionSuspended(int cause) {
                Log.d(TAG, "onConnectionSuspended() was called with cause: " + cause);
                com.google.sample.cast.refplayer.utils.Utils.
                        showToast(ClientActivity.this, R.string.connection_temp_lost);
            }

            @Override
            public void onConnectivityRecovered() {
                com.google.sample.cast.refplayer.utils.Utils.
                        showToast(ClientActivity.this, R.string.connection_recovered);
            }

            @Override
            public void onCastDeviceDetected(final RouteInfo info) {
                if (!CastPreference.isFtuShown(ClientActivity.this) && mIsHoneyCombOrAbove) {
                    CastPreference.setFtuShown(ClientActivity.this);
                    Log.d(TAG, "Route is visible: " + info);

                    new Handler().postDelayed(new Runnable() {

                        @Override
                        public void run() {
                            if (mediaRouteMenuItem.isVisible()) {
                                Log.d(TAG, "Cast Icon is visible: " + info.getName());
                                showFtu();
                            }
                        }
                    }, 1000);
                }
            }


            @Override
            public void onReconnectionStatusChanged(int status) {
                Log.d(TAG, "onReconnectionStatusChanged(): " + status);
            }

//            @Override
//            public void onCastAvailabilityChanged(boolean castPresent) {
//                MediaRouteButton mMediaRouteButton = (MediaRouteButton) findViewById(R.id.media_route_button);
//                if (mediaRouteMenuItem != null) {
//                    mMediaRouteButton.setVisibility(castPresent ? View.VISIBLE :
//                            View.INVISIBLE);
//                }
//            }
        };

        setupActionBar();
        castManager.reconnectSessionIfPossible();
    }

    private void setupActionBar() {
        mToolbar = (Toolbar) findViewById(R.id.toolbar);
        mToolbar.setLogo(R.drawable.actionbar_logo_castvideos);
        mToolbar.setTitle("");
        setSupportActionBar(mToolbar);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);
        getMenuInflater().inflate(R.menu.main, menu);
        mediaRouteMenuItem = castManager.
                addMediaRouterButton(menu, R.id.media_route_menu_item);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.action_settings:
                Intent i = new Intent(ClientActivity.this, CastPreference.class);
                startActivity(i);
                break;
        }
        return true;
    }

    /**
     * The getActionView() method used in this method requires API 11 or above. If one needs to
     * extend this below that version, one possible solution could be using reflection and such.
     */
    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
    private void showFtu() {
        Menu menu = mToolbar.getMenu();
        View view = menu.findItem(R.id.media_route_menu_item).getActionView();
        if (view != null && view instanceof MediaRouteButton) {
            new ShowcaseView.Builder(this)
                    .setTarget(new ViewTarget(view))
                    .setContentTitle(R.string.touch_to_cast)
                    .build();
        }
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        if (castManager.onDispatchVolumeKeyEvent(event, CastApplication.VOLUME_INCREMENT)) {
            return true;
        }
        return super.dispatchKeyEvent(event);
    }

    @Override
    protected void onResume() {
        Log.d(TAG, "onResume() was called");
        castManager = CastApplication.getCastManager();
        castManager.addVideoCastConsumer(castConsumer);
        castManager.incrementUiCounter();

        try {
            Long position = castManager.getCurrentMediaPosition();
            currentMediaPosition = position != null ? position.intValue() : null;

            Log.d(TAG, "Remote media position: " + currentMediaPosition);
        } catch (TransientNetworkDisconnectionException tnde) {
            Log.d(TAG, "Transient Network Disconnection Exception");
        } catch (NoConnectionException nce) {
            Log.d(TAG, "No Connection Exception");
        }

        super.onResume();
    }

    @Override
    protected void onPause() {
        castManager.decrementUiCounter();
        castManager.removeVideoCastConsumer(castConsumer);
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "onDestroy is called");
        if (null != castManager) {
            mMini.removeOnMiniControllerChangedListener(castManager);
            castManager.removeMiniController(mMini);
        }
        super.onDestroy();
    }


    @Override
    public void gotProblem(final Problem p) {
        Log.e(TAG, "Problem: " + p.toString());
        if (p.getMessage() != null)
            displayMessage(p.getMessage() + "(" + p.getErrorCode() + ")");
    }

    private void displayMessage(final String error) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(ClientActivity.this, error, Toast.LENGTH_LONG).show();
            }
        });
    }

    @Override
    public void onBackPressed() {
        shutdown();

    }

    private void shutdown() {
        OctoStatic.terminate(new Runnable() {
            @Override
            public void run() {
                finish();
            }
        });
    }
}
