package tv.freewheel.ad.interfaces;

/**
 * The IConstants interface contains all the constants for ad serving and rendering
 */
public interface IConstants {
	
    /** 
     * Capability status is on.
     */
    public int CAPABILITY_STATUS_ON();
    
    /** 
     * Capability status is off.
     */
    public int CAPABILITY_STATUS_OFF();

    /** 
     * Capability status is default.
     */
    public int CAPABILITY_STATUS_DEFAULT();

    /** 
     * Custom id provided by non-FreeWheel parties.
     */
    public int ID_TYPE_CUSTOM();

    /** 
     * Unique id provided by FreeWheel.
     */
    public int ID_TYPE_FW();

    /** 
     * Unique group id provided by FreeWheel.
     */
    public int ID_TYPE_FWGROUP();
    
    /** 
     * The request will be on on-demand mode. 
     */
	public int REQUEST_MODE_ON_DEMAND();
	
    /** 
     * The request will be on live mode.
     */
	public int REQUEST_MODE_LIVE();
    
    /** 
     * The video asset has exact length of duration. 
     */
	public int VIDEO_ASSET_DURATION_TYPE_EXACT();
	
    /** 
     * The video asset has variable length of duration.
     */
	public int VIDEO_ASSET_DURATION_TYPE_VARIABLE();
	
    /** 
     * The video asset does not play automatically.
     */
	public int VIDEO_ASSET_AUTO_PLAY_TYPE_NONE();
	
    /** 
     * The video asset plays automatically with user attended.
     */
	public int VIDEO_ASSET_AUTO_PLAY_TYPE_ATTENDED();
	
    /** 
     * The video asset plays automatically without user attended.
     */
	public int VIDEO_ASSET_AUTO_PLAY_TYPE_UNATTENDED();
   
    /** 
     * Current video is playing.
     */
    public int VIDEO_STATE_PLAYING();
    
    /** 
     * Current video is paused.
     */
    public int VIDEO_STATE_PAUSED();
	
    /** 
     * Current video is stopped.
     */
    public int VIDEO_STATE_STOPPED();
	
    /** 
     * Current video is completed.
     */
    public int VIDEO_STATE_COMPLETED();
	
    /** 
     * Type of slot: temporal slot.
     */
    public int SLOT_TYPE_TEMPORAL();
	
    /** 
     * Type of slot: non-temporal slot in video player.
     */
    public int SLOT_TYPE_VIDEOPLAYER_NONTEMPORAL();
	
    /** 
     * Type of slot: non-temporal slot in site section.
     */
    public int SLOT_TYPE_SITESECTION_NONTEMPORAL();

    /** 
     * response level param
     */
    public int PARAMETER_LEVEL_PROFILE();

    /** 
     * global level param.
     */
    public int PARAMETER_LEVEL_GLOBAL();

    /** 
     * slot level param.
     */
    public int PARAMETER_LEVEL_SLOT();

    /** 
     * creative level param.
     */
    public int PARAMETER_LEVEL_CREATIVE();

    /** 
     * rendition level param.
     */
    public int PARAMETER_LEVEL_RENDITION();

    /** 
     * override level param, highest priority.
     */
    public int PARAMETER_LEVEL_OVERRIDE();
	
    /**
     * specify Activity is in onCreate
     */
    public int ACTIVITY_STATE_CREATE();
    
    /**
     * specify Activity is in onStart
     */
    public int ACTIVITY_STATE_START();
    
    /**
     * specify Activity is in onRestart
     */
    public int ACTIVITY_STATE_RESTART();
    
    /**
     * specify Activity is in onPause
     */
    public int ACTIVITY_STATE_PAUSE();
    
    /**
     * specify Activity is in onResume
     */
    public int ACTIVITY_STATE_RESUME();
    
    /**
     * specify Activity is in onStop
     */
    public int ACTIVITY_STATE_STOP();
    
    /**
     * specify Activity is in onDestroy
     */
    public int ACTIVITY_STATE_DESTROY();
    
    /**
     * specify Activity is in onCreate
     */
    public int ACTIVITY_CALLBACK_CREATE();
    
    /**
     * specify Activity is in onStart
     */
    public int ACTIVITY_CALLBACK_START();
    
    /**
     * specify Activity is in onRestart
     */
    public int ACTIVITY_CALLBACK_RESTART();
    
    /**
     * specify Activity is in onPause
     */
    public int ACTIVITY_CALLBACK_PAUSE();
    
    /**
     * specify Activity is in onResume
     */
    public int ACTIVITY_CALLBACK_RESUME();
    
    /**
     * specify Activity is in onStop
     */
    public int ACTIVITY_CALLBACK_STOP();
    
    /**
     * specify Activity is in onDestroy
     */
    public int ACTIVITY_CALLBACK_DESTROY();
    
    /** 
     * AdManager publishes notification of this topic after ad request completed.
     */
    public String EVENT_REQUEST_COMPLETE();

    /**
     * AdManager publishes notification of this topic when a temporal slot 
     * will played and need content video to pause.
     */
    public String EVENT_REQUEST_CONTENT_VIDEO_PAUSE();
    
    /**
     * AdManager publishes notification of this topic when a temporal slot 
     * play end and need content video to resume.
     */
    public String EVENT_REQUEST_CONTENT_VIDEO_RESUME();
    
    /**
     * AdManager publishes notification of this topic before slot start.
     */
    public String EVENT_SLOT_STARTED();
    
    /** 
     * AdManager publishes notification of this topic after slot ended.
     */
    public String EVENT_SLOT_ENDED();
    
    /** 
     * AdManager publishes notification of this topic after slot preload completed.
     */
    public String EVENT_SLOT_PRELOADED();
    
    public String EVENT_USER_ACTION_NOTIFIED();
    
    /**
     * AdManager publishes the event on the activity state changed
     */
    public String EVENT_ACTIVITY_STATE_CHANGED();
    
    /**
     * AdManager publishes the event when a Player Extension is loaded
     * @return extensionLoaded
     */
    public String EVENT_EXTENSION_LOADED();

    /**
     * Predefined ad unit: preroll.
     *
     */
    public String ADUNIT_PREROLL();
    
    /**
     * Predefined ad unit: midroll.
     * 
     */
    public String ADUNIT_MIDROLL();

    /**
     * Predefined ad unit: postroll.
     * 
     */
    public String ADUNIT_POSTROLL();

    /**
     * Predefined ad unit: overlay.
     * 
     */
    public String ADUNIT_OVERLAY();
    
    /**
     * Predefined ad unit: pause_midroll.
     * 
     */
    public String ADUNIT_PAUSE_MIDROLL();

    public String ADUNIT_UNKNOWN();

    /**
     * Not used by now
     */
    public String ADUNIT_STREAM_PREROLL();

    /**
     * Not used by now
     */
    public String ADUNIT_STREAM_POSTROLL();

    /** 
     * Time position class type: preroll.
     */
    public int TIME_POSITION_CLASS_PREROLL();

    /** 
     * Time position class type: midroll.
     */
    public int TIME_POSITION_CLASS_MIDROLL();

    /** 
     * Time position class type: postroll.
     */
    public int TIME_POSITION_CLASS_POSTROLL();
    
    /** 
     * Time position class type: overlay.
     */
    public int TIME_POSITION_CLASS_OVERLAY();

    /** 
     * Time position class type: display.
     */
    public int TIME_POSITION_CLASS_DISPLAY();
    
    /** 
     * Time position class type: pause_midroll.
     */
    public int TIME_POSITION_CLASS_PAUSE_MIDROLL();

    /**
     *	Player expects template-based slots generated by ad server.
     *	<p> <h3>This is on by default</h3> </p>
     */
    public String CAPABILITY_SLOT_TEMPLATE();

    /**
     *	Ad unit in multiple slots.
     *	<p>	<h3>This is on by default</h3> </p>
     */
    public String CAPABILITY_ADUNIT_IN_MULTIPLE_SLOTS();

    /**
     * Bypass commercial ratio restriction.
     */
    public String CAPABILITY_BYPASS_COMMERCIAL_RATIO_RESTRICTION();

    /**
     *	Player expects ad server to check companion for candidate ads.
     *	<p>	<h3>This is on by default</h3> </p>
     */
    public String CAPABILITY_CHECK_COMPANION();

    /**
     *	Player expects ad server to check targeting for candidate ads.
     */
    public String CAPABILITY_CHECK_TARGETING();

    public String CAPABILITY_SLOT_CALLBACK();

    /**
     *	Whether or not video view will be recorded implicitly.
     */
    public String CAPABILITY_RECORD_VIDEO_VIEW();

    public String CAPABILITY_RESET_EXCLUSIVITY();

    /**
     *	Player expects ad server synchronize the request state between multiple request. 
     */
    public String CAPABILITY_SYNC_MULTI_REQUESTS();

    
    public String CAPABILITY_REQUIRES_RENDERER_MANIFEST();

	/**
	 * Player expects multiple creative renditions for an ad.
	 * <p> <h3>This is on by default</h3> </p>
	 */
	public String CAPABILITY_MULTIPLE_CREATIVE_RENDITIONS();
    
    /**
     *	Event name: slot impression.
     */
    public String EVENT_SLOT_IMPRESSION();

    /**
     *	Event name: ad impression.
     */
    public String EVENT_AD_IMPRESSION();
    
    /**
     *	Event name: ad impression end.
     */
    public String EVENT_AD_IMPRESSION_END();

    /**
     *	Event name: ad quartile.
     */
    public String EVENT_AD_QUARTILE();

    /**
     *	Event name: ad first quartile.	
     */
    public String EVENT_AD_FIRST_QUARTILE();

    /**
     *	Event name: ad midroll.
     */
    public String EVENT_AD_MIDPOINT();

    /**
     *	Event name: ad third quartile.	
     */
    public String EVENT_AD_THIRD_QUARTILE();

    /**
     *	Event name: ad complete.
     */
    public String EVENT_AD_COMPLETE();

    /**
     *	Event name: ad click.
     */
    public String EVENT_AD_CLICK();

    /**
     *	Event name: ad mute.
     */
    public String EVENT_AD_MUTE();

    /**
     *	Event name: ad unmute.
     */
    public String EVENT_AD_UNMUTE();

    /**
     *	Event name: ad collapse.
     */
    public String EVENT_AD_COLLAPSE();

    /**
     *	Event name: ad expand.
     */
    public String EVENT_AD_EXPAND();

    /**
     *	Event name: ad pause.
     */
    public String EVENT_AD_PAUSE();

    /**
     *	Event name: ad resume.
     */
    public String EVENT_AD_RESUME();

    /**
     *	Event name: ad rewind.
     */
    public String EVENT_AD_REWIND();

    /**
     *	Event name: ad accept invitation.
     */
    public String EVENT_AD_ACCEPT_INVITATION();

    /**
     *	Event name: ad close.
     */
    public String EVENT_AD_CLOSE();

    /**
     *	Event name: ad minimize.
     */
    public String EVENT_AD_MINIMIZE();
    
    /**
     *	Event name: ad loaded. only for RDK use
     */
    public String EVENT_AD_LOADED();
    
    /**
     *	Event name: ad started. only for RDK use
     */
    public String EVENT_AD_STARTED();
    
    /**
     *	Event name: ad stopped. only for RDK use
     */
    public String EVENT_AD_STOPPED();

	/**
	 * Event name: ad temporally paused internally in order to buffer more data. only for RDK use.
	 */
	public String EVENT_AD_BUFFERING_START();

	/**
	 * Event name: ad resumed internally after filling buffers. only for RDK use.
	 */
	public String EVENT_AD_BUFFERING_END();

    /**
     *	Event name: error.
     */
    public String EVENT_ERROR();

	/**
	 *
	 * Event name: reseller no ad
	 */
    public String EVENT_RESELLER_NO_AD();

    /**
     *	Event type: click tracking.
     */
    public String EVENT_TYPE_CLICK_TRACKING();

    /**
     *	Event type: impression.
     */
    public String EVENT_TYPE_IMPRESSION();
    
    /**
     *	Event type: click.
     */
    public String EVENT_TYPE_CLICK();

    /**
     *	Event type: standard.
     */
    public String EVENT_TYPE_STANDARD();

    /**
     * Not used by now
     */
    public String PARAMETER_TRANSPARENT_BACKGROUND();

    /**
     * Not used by now
     */
    public String PARAMETER_NONTEMPORAL_SLOT_VISIBILITY_AUTO_TRACKING();

    /**
     * Not used by now
     */
    public String PARAMETER_VIDEO_AD_SCALING_MODE();

    /**
     * Not used by now
     */
    public String PARAMETER_VIDEO_AD_SCALING_MODE_NONE();

    /**
     * Not used by now
     */
    public String PARAMETER_VIDEO_AD_SCALING_MODE_ASPECT_FIT();

    /**
     * Not used by now
     */
    public String PARAMETER_VIDEO_AD_SCALING_MODE_ASPECT_FILL();

    /**
     * Not used by now
     */
    public String PARAMETER_VIDEO_AD_SCALING_MODE_FILL();
    
    /**
     * Specify the Display ad Tap Area width.
     * <br/>value can be a int to specify the width in pixel of String "xx%" to specify the width in percentage
     */
    public String PARAMETER_CLICK_VIEW_WIDTH();

    /**
     * Specify the Display ad Tap Area height.
     * <br/>value can be a int to specify the width in pixel of String "xx%" to specify the height in percentage
     */
    public String PARAMETER_CLICK_VIEW_HEIGHT();
    
    /**
     * Specify whether enable the Display ad HTML content click processing. 
     * <br/>value can be string "true", "false". Default is "false".
     */
    public String PARAMETER_DISPLAY_AD_HTML_CONTENT_CLICK_PROCESSING();

	/**
	 * Specify whether renderer should handle user tapping on a temporal ad.
	 * <br/>value can be string "true", "false". Default is "true".
	 * <br/>Note: Note: if the value is set to "false", app should handle the ad click by itself,
	 * <br/>for example, opening the click through url in a browser.
	 */
	public String PARAMETER_CLICK_DETECTION();

	/**
     * The dictionary key value for retrieving overridden url to open on ad click event.
     */
    public String INFO_KEY_URL();
    /**
     * The dictionary key value for retrieving customId info 
     */
    public String INFO_KEY_CUSTOM_ID();
    
    /**
     * The dictionary key value for retrieving event message
     */
    public String INFO_KEY_MESSAGE();
    
    /**
     * The dictionary key value to specify whether the event success <br/>
     * only used in request complete event
     */
    public String INFO_KEY_SUCCESS();
    
    public String INFO_KEY_EXTRA_INFO();
    
    /**
     * The dictionary key value for retrieving adId message
     */
    public String INFO_KEY_AD_ID();
    
    /**
     * The dictionary key value for retrieving creativeId message
     */
	public String INFO_KEY_CREATIVE_ID();
	
	public String INFO_KEY_USER_ACTION();
    
    /**
     * The dictionary key of EVENT_ACTIVITY_STATE_CHANGED event
	 * 
	 * supported values:
	 * 			<br/>ACTIVITY_CALLBACK_PAUSE
	 * 			<br/>ACTIVITY_CALLBACK_RESUME
	 * 
     */
	public String INFO_KEY_ACTIVITY_STATE();
	
    /**
     * Not used by now
     */
    public String INFO_KEY_MODULE_TYPE();
    
    /**
     * The dictionary key of EVENT_EXTENSION_LOADED event
     * @return the loaded extension's name
     */
    public String INFO_KEY_MODULE_NAME();

    /**
     * Value for key INFO_KEY_MODULE_TYPE, indicate the module is a renderer
     */
    public String MODULE_TYPE_RENDERER();

    /**
     * Value for key INFO_KEY_MODULE_TYPE, indicate the module is a translator
     */
    public String MODULE_TYPE_TRANSLATOR();

    /**
     * The dictionary key value for error code. only for RDK use
     */
    public String INFO_KEY_ERROR_CODE();

    /**
     * The dictionary key value for additional error message. only for RDK use
     */
    public String INFO_KEY_ERROR_INFO();

    /**
     * Error type IO error.only for RDK use
     */
    public String ERROR_IO();

    /**
     * Error type timeout error.only for RDK use
     */
    public String ERROR_TIMEOUT();

    /**
     * Error type null asset error.only for RDK use
     */
    public String ERROR_NULL_ASSET();

    /**
     * Error type null adInstance unavailable.only for RDK use
     */
    public String ERROR_ADINSTANCE_UNAVAILABLE();

    /**
     * Error type unknown.only for RDK use
     */
    public String ERROR_UNKNOWN();

    /**
     * Error type missing parameter.only for RDK use
     */
    public String ERROR_MISSING_PARAMETER();

    /**
     * Error type no ad available.only for RDK use
     */
    public String ERROR_NO_AD_AVAILABLE();

    /**
     * Error type parse error.only for RDK use
     */
    public String ERROR_PARSE();

    /**
     * Error type invalid value.only for RDK use
     */
    public String ERROR_INVALID_VALUE();

    /**
     * Error type no renderer.only for RDK use
     */
    public String ERROR_NO_RENDERER();
    
    /**
     * Error type invalid slot. Only for RDK use
     */
    public String ERROR_INVALID_SLOT();
    
    /**
     * Error type unsupported 3rd party feature. Only for RDK use
     */
    public String ERROR_UNSUPPORTED_3P_FEATURE();
    
    /**
     * Error type renderer init fails. Only for RDK use
     */
    public String ERROR_RENDERER_INIT();
    
    /**
     * Error type 3rd part component error. Only for RDK use
     */
    public String ERROR_3P_COMPONENT();

    /**
     * Not used by now
     */
    public String INFO_KEY_CUSTOM_EVENT_NAME();
    
    /**
     * Not used by now
     */
    public String INFO_KEY_SHOW_BROWSER();
    
    /**
     *  @deprecated 
     */
    public int EVENT_CODE_SUCCESS();
    
    /**
     *  @deprecated 
     */
    public int EVENT_CODE_FAIL();
    
    /**
	 *	Display a new ad in the nontemporal slot
	 */
	public int SLOT_OPTION_INITIAL_AD_STAND_ALONE();

	/**
	 *	Keep the original ad in the nontemporal slot
	 */
	public int SLOT_OPTION_INITIAL_AD_KEEP_ORIGINAL();

	/**
	 *	Ask ad server to fill this slot with the first companion ad, or keep the original ad if there is no companion ad.
	 */
	public int SLOT_OPTION_INITIAL_AD_FIRST_COMPANION_ONLY();

	/**
	 *	Ask ad server to fill this slot with the first companion ad, or display a new stand alone ad 
	 */
	public int SLOT_OPTION_INITIAL_AD_FIRST_COMPANION_OR_STAND_ALONE();

	/**
	 *	Ask ad server to fill this slot with the first companion ad, or display a new stand alone ad if there is no companion ad
	 */
	public int SLOT_OPTION_INITIAL_AD_FIRST_COMPANION_THEN_STAND_ALONE();

	/**
	 *	Ask ad server to fill this slot with the first companion ad, but never deliver a standAlone ad if there is no companion ad
	 */
	public int SLOT_OPTION_INITIAL_AD_FIRST_COMPANION_OR_NO_STAND_ALONE();

	/**
	 *	Ask ad server to fill this slot only with the PREROLL slot's companion ad if there is one	
	 */
	public int SLOT_OPTION_INITIAL_AD_NO_STAND_ALONE();

	/**
	 *	Ask ad server to fill this slot with a standAlone ad only when no temporal ad will be delivered, if there is any temporal ad selected, let this slot empty
	 */
	public int SLOT_OPTION_INITIAL_AD_NO_STAND_ALONE_IF_TEMPORAL();

	/**
	 *	Ask ad server to fill this slot with a standAlone ad only when no temporal ad will be delivered, if there is any temporal ad selected, let this slot empty, but if there is companion, can use this companion to initial this slot
	 */
	public int SLOT_OPTION_INITIAL_AD_FIRST_COMPANION_OR_NO_STAND_ALONE_IF_TEMPORAL();
	
	/**
	 *  Specify the postal code of the user for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_POSTAL_CODE();

	/**
	 *  Specify the area code of the user's phone for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_AREA_CODE();

	/**
	 *  Specify the user's date of birth for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_DATE_OF_BIRTH();

	/**
	 *  Specify the user's gender for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_GENDER();

	/**
	 *  Specify a list of keywords for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_KEYWORDS();

	/**
	 *  Specify the area code of the user's phone for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_SEARCH_STRING();

	/**
	 *  Specify the user's marital status for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_MARITAL();

	/**
	 *  Specify the user's ethnicity for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_ETHNICITY();

	/**
	 *  Specify the user's orientation for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_ORIENTATION();

	/**
	 *  Specify the user's income for targeting passthrough to 3rd party component.
	 */
	public String PARAMETER_INCOME();
	
	/**
	 * 	Should be a string value which can convert to a int to indicate the milliseconds of 
	 *	renderer load timeout value.
	 */
	public String RENDERER_LOAD_TIMEOUT_VALUE();

    /**
     * Whether to enable automatic retrieval and sending of Android ID when the id is available
     */
    public String PARAMETER_ANDROID_ID();
	
	/**
	 *	User action when pause button is clicked
	 */
	public int USER_ACTION_PAUSE_BUTTON_CLICKED();
	
	/**
	 *	User action when resume button is clicked
	 */
	public int USER_ACTION_RESUME_BUTTON_CLICKED();
}
