package tv.freewheel.ad.interfaces;

import java.util.ArrayList;

/**
 *	Interface for creative rendition, only for renderer use by now
 */
public interface ICreativeRendition {
	/**
	 * Get id of the rendition
	 */
	public int getId();

	/**
	 *	Get content type of the rendition
	 *	@return  Content type in String
	 */
	public String getContentType();
	
	/**
	 * Set content type of the rendition
	 * @param contentType Content type of the rendition
	 */
	public void setContentType(String contentType);
	
	/**
	 *	Get width of the rendition
	 *	@return Width in pixels
	 */
	public int getWidth();
	
	/**
	 * Set the width of the rendition
	 * @param width Width in pixels
	 */
	public void setWidth(int width);
	
	/**
	 *	Get height of the rendition
	 *	@return Height in pixels
	 */
	public int getHeight();
	
	/**
	 * Set the height of the rendition
	 * @param height Height in pixels
	 */
	public void setHeight(int height);
	
	/**
	 *	Get duration of the rendition
	 *	@return Duration in seconds
	 */
	public double getDuration();
	
	/**
	 * Set the duration of the rendition
	 * @param duration Duration in seconds
	 */
	public void setDuration(double duration);
	
	/**
	 *	Get preference of the rendition
	 *	@return A int value, the higher is preferred among all renditions in the creative
	 */
	public int getPreference();
	
	/**
	 * Set the preference of the duration
	 * @param preference Integer, the larger the more preferred.
	 */
	public void setPreference(int preference);
	
	/**
	 * Get the creative API supported by the rendition
	 * @return Creative API in a String
	 */
	public String getCreativeAPI();
	
	/**
	 * Set the creative API supported by the rendition
	 * @param creativeApi Creative API in a String
	 */
	public void setCreativeAPI(String creativeApi);
	
	/**
	 *	Get wrapper type of the rendition
	 *	@return  Wrapper type in a String
	 */
	public String getWrapperType();
	
	/**
	 * Set the wrapper type of the rendition
	 * @param wrapperType Wrapper type in a String
	 */
	public void setWrapperType(String wrapperType);
	
	/**
	 *	Get wrapper url of the rendition
	 *	@return  Wrapper url in a String
	 */
	public String getWrapperURL();
	
	/**
	 * Set the wrapper URL of the rendition
	 * @param wrapperURL Wrapper URL in a String
	 */
	public void setWrapperURL(String wrapperURL);
	
	/**
	 * Get rendition's base unit
	 * @return base unit in String
	 */
	public String getBaseUnit();
	
	/**
	 *	Get primary asset of the rendition
	 *	@return An object of ICreativeRenditionAsset
	 */
	public ICreativeRenditionAsset getPrimaryCreativRenditionAsset();
	
	/**
	 *	Get all non-primary assets of the rendition
	 *	@return An ArrayList of ICreativeRenditionAsset
	 */
	public ArrayList<ICreativeRenditionAsset> getOtherRenditionAssets();
	
	/**
	 * Set parameter on the rendition
	 * @param name Name of the parameter
	 * @param value Value of the parameter
	 */
	public void setParameter(String name, Object value);
	
	/**
	 * Create a creative rendition asset and add it to the creative rendition.
	 * @param name Name of the asset
	 * @param isPrimary Whether or not to set the created asset as the primary asset
	 * @return The creative rendition asset that has been created.
	 */
	public ICreativeRenditionAsset createCreativeRenditionAssetForTranslation(String name, boolean isPrimary);
}
